@@ -24,11 +24,11 @@ Email::ExactTarget - Interface to ExactTarget's API.
 
 =head1 VERSION
 
-Version 1.6.0
+Version 1.6.1
 
 =cut
 
-our $VERSION = '1.6.0';
+our $VERSION = '1.6.1';
 
 our $ENDPOINT_LIVE = 'https://webservice.exacttarget.com/Service.asmx';
 
@@ -490,8 +490,8 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-email-exacttarget at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-ExactTarget>.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/Email-ExactTarget/issues/new>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -507,9 +507,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Email-ExactTarget>
+L<https://github.com/guillaumeaubert/Email-ExactTarget/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -519,9 +519,9 @@ L<http://annocpan.org/dist/Email-ExactTarget>
 
 L<http://cpanratings.perl.org/d/Email-ExactTarget>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Email-ExactTarget/>
+L<https://metacpan.org/release/Email-ExactTarget>
 
 =back
 
