@@ -21,11 +21,11 @@ Email::ExactTarget::Subscriber - Object representing ExactTarget subscribers.
 
 =head1 VERSION
 
-Version 1.6.0
+Version 1.6.1
 
 =cut
 
-our $VERSION = '1.6.0';
+our $VERSION = '1.6.1';
 
 
 =head1 SYNOPSIS
@@ -673,9 +673,10 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-email-exacttarget at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-ExactTarget>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/Email-ExactTarget/issues/new>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 
 =head1 SUPPORT
@@ -689,9 +690,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Email-ExactTarget>
+L<https://github.com/guillaumeaubert/Email-ExactTarget/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -701,9 +702,9 @@ L<http://annocpan.org/dist/Email-ExactTarget>
 
 L<http://cpanratings.perl.org/d/Email-ExactTarget>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Email-ExactTarget/>
+L<https://metacpan.org/release/Email-ExactTarget>
 
 =back
 
